@@ -17,6 +17,9 @@ class Query(ContextBase):
         self.name = ''
         self.model = ''
         self.module = ''
+        self.select_models = []
+        self._types['select_models'] = str
+        # self.select_from = ''
         self.summary = ''
         self.description = ''
         self.max_size = None     # 一个请求允许的最大返回值
@@ -31,5 +34,6 @@ class Query(ContextBase):
         self._types['joins'] = str
         self.outerjoins = []
         self._types['outerjoins'] = str
+        self.distinct = ''
         self.orders = []
         self._types['orders'] = str
