@@ -5,6 +5,7 @@
 from fastcodedog.context.contextbase import ContextBase
 from fastcodedog.context.model.column import Column
 from fastcodedog.context.model.computed_property import ComputedProperty
+from fastcodedog.context.model.additional_method import AdditionalMethod
 from fastcodedog.context.model.relationship import Relationship
 
 
@@ -25,3 +26,5 @@ class Model(ContextBase):
         self._types['relationships'] = Relationship
         self.computed_properties = {}
         self._types['computed_properties'] = ComputedProperty
+        self.additional_methods = {}
+        self._types['additional_methods'] = AdditionalMethod
