@@ -19,3 +19,5 @@ class Relationship(ContextBase):
         self.disabled = False  # 禁用。和上面的no_backup是一对
         self.from_join_table = False  # 是否是join_table
         self.is_list = False  # 是否是列表
+        self.primaryjoin = ''  # 主连接条件
+        self.secondaryjoin = ''  # 次连接条件
