@@ -33,6 +33,10 @@ class Table:
             for child_reference in self.child.child_side_references:
                 if child_reference.parent != self.parent:
                     return child_reference
+            # 从自身到自身的多对多关系，比如，质检定单和普通采样定单之间的多对多关系
+            for child_reference in self.child.child_side_references:
+                if child_reference.child_column.code != self.child_column.code:
+                    return child_reference
             return None
 
     def __init__(self, node, pdm_file):
@@ -146,9 +150,19 @@ class Table:
         back_populates_module = another_side_reference.parent.module
         secondary = reference.child.code
         secondary_object_name = reference.child.get_model_name()  # crud中需要
-        return {'name': name, 'original_name': original_name, 'back_populates_module': back_populates_module,
+        primaryjoin = f"{reference.parent.get_model_name()}.{reference.parent_column.code}=={reference.child.code}.c.{reference.child_column.code}"
+        secondaryjoin = f"{another_side_reference.parent.get_model_name()}.{another_side_reference.parent_column.code}=={another_side_reference.child.code}.c.{another_side_reference.child_column.code}"
+
+        ret = {'name': name, 'original_name': original_name, 'back_populates_module': back_populates_module,
                 'back_populates_model': back_populates_model, 'back_populates': back_populates, 'secondary': secondary,
                 'secondary_object_name': secondary_object_name, 'from_join_table': True, 'is_list': True}
+        if (reference.child == another_side_reference.child
+                and reference.parent == another_side_reference.parent
+                and reference.parent_column.code == another_side_reference.parent_column.code):
+            # 如果是同一个表的多对多关系
+            ret['primaryjoin'] = primaryjoin
+            ret['secondaryjoin'] = secondaryjoin
+        return ret
 
     def get_sub_object_name_by_foreign_key(self, foreign_key):
         """根据外键生成子对象名"""
